DefaultListTile<T> class

The default widget that will be presented on the list.

Inheritance

Constructors

DefaultListTile({required bool deleteMode, required bool editMode, required ValueItem<T> item, required dynamic onDelete(ValueItem<T> value), required dynamic onEdit(ValueItem<T> value), required dynamic onPressed(ValueItem<T> value), required SimpleOverlaySettings overlayListSettings, required bool selected, required Widget? defaultAditionalWidget, Key? key})
const

Properties

defaultAditionalWidget Widget?
final
deleteMode bool
final
editMode bool
final
hashCode int
The hash code for this object.
no setterinherited
item ValueItem<T>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDelete → dynamic Function(ValueItem<T> value)
final
onEdit → dynamic Function(ValueItem<T> value)
final
onPressed → dynamic Function(ValueItem<T> value)
final
overlayListSettings SimpleOverlaySettings
The overlay list of items settings.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DefaultListTile<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited