newValueItem property
Function that defines how the user input transforms into a new ValueItem on the list.
Ex:newValueItem: (input) => ValueItem(label: input, value: input)
Implementation
final ValueItem<T> Function(String input)? newValueItem;
Function that defines how the user input transforms into a new ValueItem on the list.
Ex:newValueItem: (input) => ValueItem(label: input, value: input)
final ValueItem<T> Function(String input)? newValueItem;