resetSelection method
void
resetSelection()
Resets the selection to its default state, clearing the current value.
Implementation
void resetSelection() {
if (mounted) {
widget.controller.resetSelection();
}
}
Resets the selection to its default state, clearing the current value.
void resetSelection() {
if (mounted) {
widget.controller.resetSelection();
}
}