SimpleOverlaySettings class

Class to hold all the customizations of the simple search overlay list.

Constructors

SimpleOverlaySettings({double dialogHeight = 200, Color? dialogBackgroundColor, EdgeInsets itemsPadding = const EdgeInsets.symmetric(horizontal: 4), Color selectedItemBackgroundColor = Colors.black38, Color selectedItemHoverColor = const Color.fromRGBO(224, 224, 224, 1), TextStyle? selectedItemTextStyle = const TextStyle(color: Colors.black), TextStyle? unselectedItemTextStyle = const TextStyle(color: Colors.black45), Color unselectedItemHoverColor = const Color.fromRGBO(245, 245, 245, 1), Icon dialogDeleteIcon = const Icon(Icons.delete, color: Color.fromRGBO(183, 28, 28, 1), size: 20), Icon dialogEditIcon = const Icon(Icons.edit, color: Colors.black, size: 20), Widget? dialogActionWidget, double separatorHeight = 1, Duration animationDuration = const Duration(milliseconds: 100), String addItemHint = 'Criar', TextStyle? addItemHintStyle, Widget itemWidgetBuilder(ValueItem)?, Duration reOpenedScrollDuration = const Duration(seconds: 1), double offsetHeight = 3, double offsetWidth = 0, double aditionalWidgetSpacing = 5, bool openFullScreen = false, Color loadingColor = darkGreen, double loadingSize = 28})
const

Properties

addItemHint String
The text of the add button when user is allowed to add items in the list (default: 'Criar').
final
addItemHintStyle TextStyle?
The style of the add button when user is allowed to add items in the list.
final
aditionalWidgetSpacing double
The width of the space between the aditional widget and the delete one (default:5).
final
animationDuration Duration
The duration of the dropdown opening animation (default:Duration(milliseconds: 100)).
final
dialogActionWidget Widget?
The delete Widget in dropdown listview (default:IconButton). It replaces the dialogActionIcon
final
dialogBackgroundColor Color?
Dropdown Container color
final
dialogDeleteIcon Icon
The delete Icon in dropdown listview (default:red trash)
final
dialogEditIcon Icon
The edit Icon in dropdown listview (default:black edit)
final
dialogHeight double
Dropdown Container height (default:200).
final
hashCode int
The hash code for this object.
no setterinherited
itemsPadding EdgeInsets
The padding for the items of the list.
final
itemWidgetBuilder Widget Function(ValueItem)?
Custom droplist item widget.
final
loadingColor Color
Loading widget default color (default:Color.fromARGB(255, 0, 67, 0))
final
loadingSize double
Loading widget default color (default:28)
final
offsetHeight double
The height of the offset from the bottom of the search bar (default:3).
final
offsetWidth double
The width of the offset from the left of the search bar (default:0).
final
openFullScreen bool
final
reOpenedScrollDuration Duration
Duration to scroll down when the drop is reopened (default: Duration(seconds: 1))
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItemBackgroundColor Color
Selected item background color
final
selectedItemHoverColor Color
The hover color of the selected item of the list.
final
selectedItemTextStyle TextStyle?
Selected item TextStyle
final
separatorHeight double
Separator between two items inside the droplist (default:1).
final
unselectedItemHoverColor Color
The hover color of the unselected items of the list.
final
unselectedItemTextStyle TextStyle?
Unselected droplist items TextStyle.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited