addItemHint property
The text of the add button when user is allowed to add items in the list (default: 'Criar').
Implementation
final String addItemHint;
The text of the add button when user is allowed to add items in the list (default: 'Criar').
final String addItemHint;