addItemHintStyle property
The style of the add button when user is allowed to add items in the list.
Implementation
final TextStyle? addItemHintStyle;
The style of the add button when user is allowed to add items in the list.
final TextStyle? addItemHintStyle;