aditionalWidgetSpacing property
The width of the space between the aditional widget and the delete one (default:5).
Implementation
final double aditionalWidgetSpacing;
The width of the space between the aditional widget and the delete one (default:5).
final double aditionalWidgetSpacing;