reOpenedScrollDuration property
Duration to scroll down when the drop is reopened (default: Duration(seconds: 1))
Implementation
final Duration reOpenedScrollDuration;
Duration to scroll down when the drop is reopened (default: Duration(seconds: 1))
final Duration reOpenedScrollDuration;