SimpleSearchbarSettings class

Class to hold all the customizations of the simple search bar.

Constructors

SimpleSearchbarSettings({double dropdownWidth = 300, double dropdownHeight = 50, double elevation = 2, Color backgroundColor = Colors.white, OutlinedBorder border = const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(10))), Color? clearIconColor, TextStyle? searchBarTextStyle, List<Widget>? actions, String hint = 'Pesquisar', TextStyle? hintStyle = const TextStyle(fontSize: 14), Color hoverColor = const Color.fromRGBO(245, 245, 245, 1), bool showArrow = true, bool showClearIcon = true, IconData dropdownClosedArrowIcon = Icons.arrow_drop_down, IconData dropdownOpenedArrowIcon = Icons.arrow_drop_up, Color? outsideIconColor, double outsideIconSize = 20, dynamic dropdownClosedIconFunction()?, dynamic dropdownOpenedIconFunction()?, bool clearOnClose = false, double boxMultiSelectedClearIconSize = 20, Color? boxMultiSelectedClearIconColor, Widget boxMultiItemWidgetBuilder(ValueItem)?, Color boxMultiSelectedBackgroundColor = const Color.fromRGBO(224, 224, 224, 1), TextStyle? boxMultiSelectedTextStyle, EdgeInsetsGeometry? searchBarPadding, bool showKeyboardOnTap = true, TextInputType? keyboardType, TextInputAction? textInputAction, bool showDivider = false})
const

Properties

actions List<Widget>?
List of widgets that will go on the end of the search bar.
final
backgroundColor Color
The background color of the searchbar and overlay.
final
border OutlinedBorder
The border of the searchbar.
final
boxMultiItemWidgetBuilder Widget Function(ValueItem)?
Outside/horizontal list of selected items custom widget
final
boxMultiSelectedBackgroundColor Color
Outside/horizontal list of selected items Background color
final
boxMultiSelectedClearIconColor Color?
Outside/horizontal list of selected items clear icon color
final
boxMultiSelectedClearIconSize double
Outside/horizontal list of selected items clear icon size (default:20)
final
boxMultiSelectedTextStyle TextStyle?
Outside/horizontal list of selected items Background color
final
clearIconColor Color?
The color of "x" clear icon on the end of the searchbar.
final
clearOnClose bool
If true, the value on the Searchbar will be cleared if nothing was selected (default:false).
final
Action Icon showed when dropdown is closed
final
Function of the Icon showed when dropdown is closed
final
Main/outside Container height(default:50)
final
Action Icon showed when dropdown is opened
final
Function of the Icon showed when dropdown is opened
final
Main/outside Container width(default:300)
final
elevation double
The elevation of the searchbar and overlay (default:2).
final
hashCode int
The hash code for this object.
no setterinherited
hint String
The text to be presented on the hint of the searchbar.
final
hintStyle TextStyle?
The style of the hint of the searchbar.
final
hoverColor Color
The hover color of the searchbar.
final
keyboardType TextInputType?
final
outsideIconColor Color?
Action dropdown Icon color
final
outsideIconSize double
Action dropdown Icon size (default:20)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchBarPadding EdgeInsetsGeometry?
The internal padding of the searchBar
final
searchBarTextStyle TextStyle?
The style of searchbar text when something is typed (default:hintStyle)
final
showArrow bool
If true, the arrow icon will appear on the end of the searchbar (default:true).
final
showClearIcon bool
If true, the "x" icon will appear on the end of the searchbar (default:true).
final
showDivider bool
If true, a divider between the searchbar and the list of items will appear (default:false).
final
showKeyboardOnTap bool
If true, the keyboard will appear when you tap the searchbar (default:true).
final
textInputAction TextInputAction?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited