simple_search_dropdown library
Classes
- ClearButton
- CustomScrollBehavior
- This allows the mouse to drag the scrollable content.
- DefaultAddListItem
- DefaultDialogContent
- Default content for the dialog.
- DefaultDialogTitle
- Default title for the dialog.
-
DefaultListTile<
T> - The default widget that will be presented on the list.
- DialogButton
- DialogButtonSettings
- Class to hold all the customizations of the buttons in the dialog.
- DialogSettings
- Class to hold all the customizations of the confirmation dialog.
- EditDialog
- InputField
- Loading
-
MultipleListView<
T> -
MultipleSearchDropDown<
T> - This creates a multiple selection dropdown widget.
-
MultipleSearchDropDownState<
T> - OverlayScreen
- Controls the overlays on the screen.
-
SearchDropDown<
T> - This creates a single-selection dropdown widget. The widget UI is defined here, while state management is handled by SearchDropDownController.
-
SearchDropDownController<
T> - Controller for SearchDropDown that manages the list data, selection, and search text.
-
SearchDropDownState<
T> - SimpleOverlaySettings
- Class to hold all the customizations of the simple search overlay list.
- SimpleSearchbarSettings
- Class to hold all the customizations of the simple search bar.
-
ValueItem<
T> - label is the item that is displayed in the list. value is the value that is returned when the item is selected. If the value is not provided, the label is used as the value. An example of a ValueItem is:
- WarningDialog
Constants
- darkGreen → const Color
- default loading color
- defaultCancelButtonSettings → const DialogButtonSettings
- Default settings for Cancel button.
- defaultDeleteButtonSettings → const DialogButtonSettings
- Default settings for Delete button.
- defaultEditButtonSettings → const DialogButtonSettings
- Default settings for edit button.
- defaultOKButtonSettings → const DialogButtonSettings
- Default settings for OK button.
- defaultOverlaySettings → const SimpleOverlaySettings
- The default settings for the OverlayList.
- defaultSearchBarSettings → const SimpleSearchbarSettings
- The default settings for the SimpleSearchbar.
Properties
- allValues ↔ FilteringTextInputFormatter
-
getter/setter pair
Functions
-
sendDialog<
T> (BuildContext context, Widget child, {dynamic barrierDismissible = false}) → Future< T?>