InputField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- InputField
Constructors
-
InputField({Key? key, required TextEditingController controle, TextInputFormatter? mascara, TextInputAction textInputButton = TextInputAction.done, TextInputType tipoTeclado = TextInputType.text, FormFieldValidator<
String> ? validator, String? hint, double width = 200, bool oculto = false, VoidCallback? finishFunction, bool clear = false, VoidCallback? tapFunction, int? lines = 1, double raio = 10, double elevacao = 0.5, ValueChanged<String> ? mudeiTextoFunction, TextStyle? estilo, bool mostrarHint = true, bool liberado = true, TextAlign alinhamento = TextAlign.start, Color? disabledColor, TextCapitalization? capitalization}) -
const
Properties
- alinhamento → TextAlign
-
final
- capitalization → TextCapitalization?
-
final
- clear → bool
-
final
- controle → TextEditingController
-
final
- disabledColor → Color?
-
final
- elevacao → double
-
final
- estilo → TextStyle
-
final
- finishFunction → VoidCallback?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- liberado → bool
-
final
- lines → int?
-
final
- mascara → TextInputFormatter?
-
final
- mostrarHint → bool
-
final
-
mudeiTextoFunction
→ ValueChanged<
String> ? -
final
- oculto → bool
-
final
- raio → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tapFunction → VoidCallback?
-
final
- textInputButton → TextInputAction
-
final
- tipoTeclado → TextInputType
-
final
-
validator
→ FormFieldValidator<
String> ? -
final
- width → double
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited