SearchDropDown<T> class
This creates a single-selection dropdown widget. The widget UI is defined here, while state management is handled by SearchDropDownController.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SearchDropDown
Constructors
-
SearchDropDown({Key? key, required SearchDropDownController<
T> controller, SimpleSearchbarSettings searchBarSettings = defaultSearchBarSettings, SimpleOverlaySettings overlayListSettings = defaultOverlaySettings, Widget? addAditionalWidget, Widget? defaultAditionalWidget, bool disposeController = true, bool removeFocus = true}) -
const
Properties
- addAditionalWidget → Widget?
-
A custom additional widget to be inserted on the add-item cell between the text and the create button.
final
-
controller
→ SearchDropDownController<
T> -
The external controller that manages state (text, selected item, etc.) for this dropdown.
final
- defaultAditionalWidget → Widget?
-
A custom additional widget to be inserted on the default item cell between the text and the delete button.
final
- disposeController → bool
-
If the controller will be disposed when this widget is disposed (default:
true).final - hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- overlayListSettings → SimpleOverlaySettings
-
The settings for the overlay list of items.
final
- removeFocus → bool
-
If the focus from the text field will be removed after the search view is closed (default:
true).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchBarSettings → SimpleSearchbarSettings
-
The SearchBar settings (visual and behavioral configuration for the search bar).
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SearchDropDown< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited